@@ -290,7 +290,7 @@ class Server(object):
                 try:
                     send(msg)
                 except Exception, e:
-                    send(('#UNSERIALIZABLE', repr(msg)))
+                    send(('#UNSERIALIZABLE', format_exc()))
             except Exception, e:
                 util.info('exception in thread serving %r',
                         threading.current_thread().name)
@@ -887,7 +887,7 @@ def RebuildProxy(func, token, serializer, kwds):
 
 def MakeProxyType(name, exposed, _cache={}):
     '''
-    Return an proxy type whose methods are given by `exposed`
+    Return a proxy type whose methods are given by `exposed`
     '''
     exposed = tuple(exposed)
     try:
